@@ -187,7 +187,9 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
             line, in_quote=in_quote, index=index, section_comments=config.section_comments
         )
 
-        if line in config.section_comments and not skipping_line:
+        if (
+            line in config.section_comments or line in config.section_comments_end
+        ) and not skipping_line:
             if import_index == -1:  # pragma: no branch
                 import_index = index - 1
             continue
@@ -447,6 +449,10 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                         f"could not place module {import_from} of line {line} --"
                         " Do you need to define a default section?"
                     )
+
+                if placed_module and placed_module not in imports:
+                    raise MissingSection(import_module=import_from, section=placed_module)
+
                 root = imports[placed_module][type_of_import]  # type: ignore
                 for import_name in just_imports:
                     associated_comment = nested_comments.get(import_name)
